aboutsummaryrefslogtreecommitdiffstats
path: root/include/osmocom/msc/a_iface.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/osmocom/msc/a_iface.h')
-rw-r--r--include/osmocom/msc/a_iface.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/osmocom/msc/a_iface.h b/include/osmocom/msc/a_iface.h
index 9a758d36b..b1b6c1cc3 100644
--- a/include/osmocom/msc/a_iface.h
+++ b/include/osmocom/msc/a_iface.h
@@ -66,7 +66,7 @@ int a_init(struct osmo_sccp_instance *sccp, struct gsm_network *network);
int a_iface_tx_dtap(struct msgb *msg);
/* Send Cipher mode command via A-interface */
-int a_iface_tx_cipher_mode(const struct gsm_subscriber_connection *conn,
+int a_iface_tx_cipher_mode(const struct ran_conn *conn,
struct gsm0808_encrypt_info *ei, int include_imeisv);
/* Page a subscriber via A-interface */
@@ -76,11 +76,11 @@ int a_iface_tx_paging(const char *imsi, uint32_t tmsi, uint16_t lac);
int a_iface_tx_assignment(const struct gsm_trans *trans);
/* Send clear command via A-interface */
-int a_iface_tx_clear_cmd(struct gsm_subscriber_connection *conn);
+int a_iface_tx_clear_cmd(struct ran_conn *conn);
-int a_iface_tx_classmark_request(const struct gsm_subscriber_connection *conn);
+int a_iface_tx_classmark_request(const struct ran_conn *conn);
-/* Clear all subscriber connections on a specified BSC
+/* Clear all RAN connections on a specified BSC
* (Helper function for a_iface_bssap.c) */
void a_clear_all(struct osmo_sccp_user *scu, const struct osmo_sccp_addr *bsc_addr);